===============
Outreach
===============

The project zfit aims to establish a basis in terms of API and basic functionality for a (likelihood) fitting
ecosystem that is capable of dealing with the demands from High Energy Physics (HEP).

Papers and proceedings
=======================

- `Original zfit paper <https://www.sciencedirect.com/science/article/pii/S2352711019303851>`_
- `Computing in High Energy Physics (CHEP) 2019 <https://www.epj-conferences.org/articles/epjconf/ref/2020/21/epjconf_chep2020_06025/epjconf_chep2020_06025.html>`_
- `PyHEP 2020 tutorial <https://zenodo.org/record/4147540#.YHSdF3UzZH4>`_
- `PyHEP 2020 presentation <https://zenodo.org/record/4147528#.YHSdkHUzZH4>`_
- `PyHEP 2019 presentation <https://zenodo.org/record/3960059#.YHSdUnUzZH4>`_

Used by
========

The following analysis have used zfit

- Search for long-lived particles decaying to :math:`$$e ^\pm $$$$\mu ^\mp $$$$\nu $$`,
  `Eur. Phys. J. C 81, 261 (2021) <https://doi.org/10.1140/epjc/s10052-021-08994-0>`_

- Angular analysis of
  :math:`$$ {B}^0\to {D}^{\ast -}{D}_s^{\ast +} $$with $$ {D}_s^{\ast +}\to {D}_s^{+}\gamma $$` decays,
  `J. High Energ. Phys. 2021, 177 (2021) <https://doi.org/10.1007/JHEP06(2021)177>`_


.. _section-citing:
Citing
======

If you use zfit in research, please consider citing:

.. code-block:: latex

    @article{ESCHLE2020100508,
    title = {zfit: Scalable pythonic fitting},
    journal = {SoftwareX},
    volume = {11},
    pages = {100508},
    year = {2020},
    issn = {2352-7110},
    doi = {https://doi.org/10.1016/j.softx.2020.100508},
    url = {https://www.sciencedirect.com/science/article/pii/S2352711019303851},
    author = {Jonas Eschle and Albert {Puig Navarro} and Rafael {Silva Coutinho} and Nicola Serra},
    keywords = {Model fitting, Data analysis, Statistical inference, Python},
    abstract = {Statistical modeling is a key element in many scientific fields and especially in
    High-Energy Physics (HEP) analysis. The standard framework to perform this task in HEP is the
    C++ ROOT/RooFit toolkit; with Python bindings that are only loosely integrated into the
    scientific Python ecosystem. In this paper, zfit, a new alternative to RooFit written in pure Python,
    is presented. Most of all, zfit provides a well defined high-level API and workflow
    for advanced model building and fitting, together with an implementation on top of TensorFlow,
    allowing a transparent usage of CPUs and GPUs. It is designed to be extendable in a
    very simple fashion, allowing the usage of cutting-edge developments from
    the scientific Python ecosystem in a transparent way. The main features of zfit are introduced,
    and its extension to data analysis, especially in the context of HEP experiments, is discussed.}
    }



Material
=========

:download:`zfit logo high resolution <../images/zfit-logo_veryhires.png>`

:download:`zfit logo normal resolution <../images/zfit-logo_hires.png>`

:download:`zfit vectorgraphics <../images/zfit-vector.svg>`

:download:`zfit favicon <../images/zfit-favicon.png>`

:download:`zfit workflow <../images/zfit_workflow_v2.png>`

If there is material missing, do not hesitate to contact us.
